# dba008.pp

# module dba
# v 008
#
# Must be used with pbs002 minimum and replication/merging of the two billings
# This version runs under debian 6.0
#
# Created on 120414 by nicolas.bondier@switzernet.com
#

import "mysql-server.pp"
import "postfix.pp"
import "perl.pp"
import "snmp.pp"

class dba008{

	$module_name = "dba008"
	include mysql-server
	include postfix	
        include perl
        include snmp

	package{[libdbi-perl, libdbd-mysql-perl, ntp, ngrep]:
		ensure      => installed,
                require     => Package["mysql-server-5.5"],
	}

        define packagesCPAN {
                perl::installCPAN {    ["YAML",
                                        "Config::IniFiles",
                                        "List::Util",
                                        "Sys::Syslog",
                                        "MIME::Lite",
                                        "Date::Manip"]:
                }
        }

        packagesCPAN{"mysql":
                require     => Package["mysql-server-5.5"]
        }


        file { "/etc/dba":
                ensure      => directory,
        }

        file{"/etc/dba/setup-mysql-replication.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/setup-mysql-replication.pl",
                require     => File["/etc/dba"]
        }

       file{"/etc/dba/exec-registration-m1.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/exec-registration-m1.pl",
                require     => File["/etc/dba"]
        }
        
        file{"/etc/dba/exec-registration-m2.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/exec-registration-m2.pl",
                require     => File["/etc/dba"]
        }

       file{"/etc/dba/exec-replication.pl":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/exec-replication.pl",
                require     => File["/etc/dba"]
        }

        file{"/etc/cron.d/dba":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/dba",
        }

        file{"/etc/dba/setup-mysql-replication.conf":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/setup-mysql-replication.conf.erb"),
                require     => File["/etc/dba"]
        }
        
        file{"/etc/dba/120329-dba.sql":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 644,
                replace     => true,
                content     => template("$module_name/120329-dba.sql.erb"),
                require     => File["/etc/dba"]
        }

        file{"/etc/dba/Lister.pm":
                ensure      => file,
                owner       => root,
                group       => root,
                mode        => 755,
                recurse     => true,
                replace     => true,
                source      => "puppet:///$module_name/Lister.pm",
                require     => File["/etc/dba"]
        }

        exec { "setup mysql replication":
#                command     => "/etc/dba/setup-mysql-replication.pl > /dev/null 2>&1",
                command     => "/etc/dba/setup-mysql-replication.pl2 > /dev/null 2>&1",
                subscribe   => [ File["/etc/dba/setup-mysql-replication.conf"], File["/etc/dba/120329-dba.sql"] ],
                refreshonly => true,
                timeout     => 0,
                require     => [ File["/etc/dba/setup-mysql-replication.conf"], File["/etc/dba/120329-dba.sql"], PackagesCPAN["mysql"], File["/etc/dba/setup-mysql-replication.pl"], Package["mysql-server-5.5"] ]
        }
}
